@@ -11,12 +11,12 @@ function(solution, taxlevels='ALL') {
             alltaxa[[nametax]] <- tmp # add extracted list as sub-object to output list and label it with the appropriate taxlevel nr.
         }
     }  # if a specific taxlevel should be focused on
-    if (taxlevels != 'ALL' & class(taxlevels) != 'numeric') {  # if named taxlevel requested
+    if (taxlevels != 'ALL' & inherits(taxlevels, 'numeric')) {  # if named taxlevel requested
       nametax <- paste(taxlevels)  # create namelabel for current taxlevel
       tmp <- solution[[taxlevels]]$OutlierTaxa  # extract sub-list of outlier taxa from solution
       alltaxa[[nametax]] <- tmp  # add extracted list as sub-object to output list and label it with the appropriate taxlevel nr.
     }
-      if (class(taxlevels) == 'numeric') {
+      if (inherits(taxlevels, 'numeric')) {
         if (taxlevels > length(solution)) {  # test whether requested taxlevel is among available ones and display error if not
             stop('Requested taxonomic level not available (less levels specified as analysis input)!')
         }
